pub fn extract_token<T>(
request: &Request<T>,
) -> Result<ForwardedToken, TokenError>Expand description
Construct from the metadata of an incoming tonic request.
pub fn extract_token<T>(
request: &Request<T>,
) -> Result<ForwardedToken, TokenError>Construct from the metadata of an incoming tonic request.